From mboxrd@z Thu Jan  1 00:00:00 1970
Return-Path: <pve-devel-bounces@lists.proxmox.com>
Received: from firstgate.proxmox.com (firstgate.proxmox.com [212.224.123.68])
	by lore.proxmox.com (Postfix) with ESMTPS id A8D0C1FF161
	for <inbox@lore.proxmox.com>; Wed,  4 Dec 2024 12:37:18 +0100 (CET)
Received: from firstgate.proxmox.com (localhost [127.0.0.1])
	by firstgate.proxmox.com (Proxmox) with ESMTP id 0F9E9663B;
	Wed,  4 Dec 2024 12:37:15 +0100 (CET)
From: Fiona Ebner <f.ebner@proxmox.com>
To: pve-devel@lists.proxmox.com
Date: Wed,  4 Dec 2024 12:37:07 +0100
Message-Id: <20241204113708.50043-5-f.ebner@proxmox.com>
X-Mailer: git-send-email 2.39.5
In-Reply-To: <20241204113708.50043-1-f.ebner@proxmox.com>
References: <20241204113708.50043-1-f.ebner@proxmox.com>
MIME-Version: 1.0
X-SPAM-LEVEL: Spam detection results:  0
 AWL -0.204 Adjusted score from AWL reputation of From: address
 BAYES_00                 -1.9 Bayes spam probability is 0 to 1%
 DMARC_MISSING             0.1 Missing DMARC policy
 KAM_DMARC_STATUS 0.01 Test Rule for DKIM or SPF Failure with Strict Alignment
 POISEN_SPAM_PILL          0.1 Meta: its spam
 POISEN_SPAM_PILL_1        0.1 random spam to be learned in bayes
 POISEN_SPAM_PILL_3        0.1 random spam to be learned in bayes
 RCVD_IN_VALIDITY_RPBL_BLOCKED 0.001 ADMINISTRATOR NOTICE: The query to
 Validity was blocked. See
 https://knowledge.validity.com/hc/en-us/articles/20961730681243 for more
 information.
 RCVD_IN_VALIDITY_SAFE_BLOCKED 0.001 ADMINISTRATOR NOTICE: The query to
 Validity was blocked. See
 https://knowledge.validity.com/hc/en-us/articles/20961730681243 for more
 information.
 SPF_HELO_NONE           0.001 SPF: HELO does not publish an SPF Record
 SPF_PASS               -0.001 SPF: sender matches SPF record
Subject: [pve-devel] [PATCH access-control 4/5] api: password: use singular
 they pronoun
X-BeenThere: pve-devel@lists.proxmox.com
X-Mailman-Version: 2.1.29
Precedence: list
List-Id: Proxmox VE development discussion <pve-devel.lists.proxmox.com>
List-Unsubscribe: <https://lists.proxmox.com/cgi-bin/mailman/options/pve-devel>, 
 <mailto:pve-devel-request@lists.proxmox.com?subject=unsubscribe>
List-Archive: <http://lists.proxmox.com/pipermail/pve-devel/>
List-Post: <mailto:pve-devel@lists.proxmox.com>
List-Help: <mailto:pve-devel-request@lists.proxmox.com?subject=help>
List-Subscribe: <https://lists.proxmox.com/cgi-bin/mailman/listinfo/pve-devel>, 
 <mailto:pve-devel-request@lists.proxmox.com?subject=subscribe>
Reply-To: Proxmox VE development discussion <pve-devel@lists.proxmox.com>
Content-Type: text/plain; charset="us-ascii"
Content-Transfer-Encoding: 7bit
Errors-To: pve-devel-bounces@lists.proxmox.com
Sender: "pve-devel" <pve-devel-bounces@lists.proxmox.com>

Signed-off-by: Fiona Ebner <f.ebner@proxmox.com>
---
 src/PVE/API2/AccessControl.pm | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/PVE/API2/AccessControl.pm b/src/PVE/API2/AccessControl.pm
index bb7b78f..c4c0699 100644
--- a/src/PVE/API2/AccessControl.pm
+++ b/src/PVE/API2/AccessControl.pm
@@ -323,8 +323,8 @@ __PACKAGE__->register_method ({
     path => 'password',
     method => 'PUT',
     permissions => {
-	description => "Each user is allowed to change his own password. A user can change the"
-	    ." password of another user if he has 'Realm.AllocateUser' (on the realm of user"
+	description => "Each user is allowed to change their own password. A user can change the"
+	    ." password of another user if they have 'Realm.AllocateUser' (on the realm of user"
 	    ." <userid>) and 'User.Modify' permission on /access/groups/<group> on a group where"
 	    ." user <userid> is member of. For the PAM realm, a password change does not take "
 	    ." effect cluster-wide, but only applies to the local node.",
@@ -371,7 +371,7 @@ __PACKAGE__->register_method ({
 	} else {
 	    if ($authuser eq $userid) {
 		$rpcenv->check_user_enabled($userid);
 		# OK - each user can change its own password
 	    } else {
 		# only root may change root password
 		raise_perm_exc() if $userid eq 'root@pam';
@@ -371,7 +371,7 @@ __PACKAGE__->register_method ({
 	    if ($authuser eq $userid) {
 		$rpcenv->check_user_enabled($userid);
-		# OK - each user can change its own password
+		# OK - each user can change their own password
 	    } else {
 		# only root may change root password
-- 
2.39.5



_______________________________________________
pve-devel mailing list
pve-devel@lists.proxmox.com
https://lists.proxmox.com/cgi-bin/mailman/listinfo/pve-devel